@@ -846,8 +846,9 @@ static PyObject* Fprofile_StartTrace(PyObject* obj, PyObject* args, PyObject* kw
             mpack_write_cstr(&initWriter, "program_name");
             mpack_write_cstr(&initWriter, moduleConfiguration.argv);
 
+            // PACKAGE_VERSION is defined in setup.py.
             mpack_write_cstr(&initWriter, "program_version");
-            mpack_write_cstr(&initWriter, "0.0.1");
+            mpack_write_cstr(&initWriter, "py-functiontrace " PACKAGE_VERSION);
 
             char versionBuf[20] = { 0 };
             snprintf(versionBuf, sizeof(versionBuf), "Python %.*s",
