@@ -4,6 +4,7 @@ import os
 import shutil
 import sys
 import tempfile
+
 import _functiontrace
 
 PYTHON_TEMPLATE = """#!/bin/sh
@@ -17,12 +18,19 @@ PATH=$(echo "$PATH" | sed -e "s#$FUNCTIONTRACE_WRAPPER_PATH:##")
 exec $(which {python}) -m functiontrace "$@"
 """
 
+
 def setup_dependencies():
     # We need the functiontrace-server installed and locatable in order to
     # trace anything.
     if shutil.which("functiontrace-server") is None:
-        print("Unable to find `functiontrace-server` in the current $PATH.", file=sys.stderr)
-        print("See https://functiontrace.com#installation for installation instructions.", file=sys.stderr)
+        print(
+            "Unable to find `functiontrace-server` in the current $PATH.",
+            file=sys.stderr,
+        )
+        print(
+            "See https://functiontrace.com#installation for installation instructions.",
+            file=sys.stderr,
+        )
         sys.exit(1)
 
     # Generate a temp directory to store our wrappers in.  We'll temporarily
@@ -39,13 +47,23 @@ def setup_dependencies():
             os.chmod(f.name, 0o755)
 
 
-if __name__ == "__main__":
+def main():
     parser = argparse.ArgumentParser(description="Trace a script's execution.")
-    parser.add_argument('--trace-memory', action="store_true", help="""Trace
+    parser.add_argument(
+        "--trace-memory",
+        "--trace_memory",
+        action="store_true",
+        help="""Trace
                         memory allocations/frees when enabled.  This may add
-                        tracing overhead, so is disabled by default.""")
-    parser.add_argument('--output_dir', type=str, default=os.getcwd(),
-                        help="The directory to output trace files to")
+                        tracing overhead, so is disabled by default.""",
+    )
+    parser.add_argument(
+        "--output-dir",
+        "--output_dir",
+        type=str,
+        default=os.getcwd(),
+        help="The directory to output trace files to",
+    )
     parser.add_argument("script", nargs=argparse.REMAINDER)
     args = parser.parse_args()
 
@@ -66,17 +84,19 @@ if __name__ == "__main__":
     # `multiprocessing.Pool` are good sanity checks if this is modified.
     target_file = sys.argv[0]
     sys.path.insert(0, os.path.dirname(target_file))
-    with open(target_file, 'rb') as fp:
-        code = compile(fp.read(), target_file, 'exec')
+    with open(target_file, "rb") as fp:
+        code = compile(fp.read(), target_file, "exec")
 
     # Load the file as __main__ and insert it into the set of modules.  This
     # won't do anything useful on its own, but is necessary for the exec() call
     # below, which needs to operate in the context of our new module.
     # NOTE: We use SourceFileLoader, rather than allowing importlib to infer
     # the proper loader, in order to support files without a .py extension.
-    spec = importlib.util.spec_from_loader("__main__", importlib.machinery.SourceFileLoader("__main__", target_file))
+    spec = importlib.util.spec_from_loader(
+        "__main__", importlib.machinery.SourceFileLoader("__main__", target_file)
+    )
     mod = importlib.util.module_from_spec(spec)
-    sys.modules.update({ "__main__": mod})
+    sys.modules.update({"__main__": mod})
 
     # Ensure we're setup to be able to run.
     setup_dependencies()
@@ -89,8 +109,13 @@ if __name__ == "__main__":
     # Run their code now that we're tracing.  This must be done in the context
     # of the __main__ module we've created.
     exec(code, mod.__dict__)
-else:
-    # We've been imported for some reason.  Make sure we're setup to work
-    # properly, then begin tracing.
+
+
+def trace():
+    # Make sure we're set up to work properly, then begin tracing.
     setup_dependencies()
     _functiontrace.begin_tracing(os.getcwd())
+
+
+if __name__ == "__main__":
+    main()
